==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CellStyleRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellStyleRequestedEventArgsDescription } from "./CellStyleRequestedEventArgsDescription";
/**
 * @hidden
 */
var CellStyleRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellStyleRequestedEventArgsDescriptionMetadata, _super);
    function CellStyleRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellStyleRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (CellStyleRequestedEventArgsDescriptionMetadata.a == null) {
            CellStyleRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellStyleRequestedEventArgsDescriptionMetadata.c(CellStyleRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.g(CellStyleRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CellStyleRequestedEventArgsDescriptionMetadata.a);
    };
    CellStyleRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("StyleKey", "String");
        a.item("ResolvedValueRef", "(w:ResolvedValue,wf:ResolvedValue)DataRef");
        a.item("RowNumber", "Number:int");
    };
    CellStyleRequestedEventArgsDescriptionMetadata.d = function (a) {
        CellStyleRequestedEventArgsDescriptionMetadata.b(a);
        a.u("CellStyleRequestedEventArgs", function () { return new CellStyleRequestedEventArgsDescription(); });
        a.t("CellStyleRequestedEventArgs", CellStyleRequestedEventArgsDescriptionMetadata.a);
    };
    CellStyleRequestedEventArgsDescriptionMetadata.$t = markType(CellStyleRequestedEventArgsDescriptionMetadata, 'CellStyleRequestedEventArgsDescriptionMetadata');
    CellStyleRequestedEventArgsDescriptionMetadata.a = null;
    return CellStyleRequestedEventArgsDescriptionMetadata;
}(Base));
export { CellStyleRequestedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CellStyleRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellStyleRequestedEventArgsDescription } from "./CellStyleRequestedEventArgsDescription";
/**
 * @hidden
 */
var CellStyleRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellStyleRequestedEventArgsDescriptionMetadata, _super);
    function CellStyleRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellStyleRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (CellStyleRequestedEventArgsDescriptionMetadata.a == null) {
            CellStyleRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellStyleRequestedEventArgsDescriptionMetadata.c(CellStyleRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.j(CellStyleRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CellStyleRequestedEventArgsDescriptionMetadata.a);
    };
    CellStyleRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("StyleKey", "String");
        a.item("ResolvedValueRef", "(w:ResolvedValue,wf:ResolvedValue)DataRef");
        a.item("RowNumber", "Number:int");
    };
    CellStyleRequestedEventArgsDescriptionMetadata.d = function (a) {
        CellStyleRequestedEventArgsDescriptionMetadata.b(a);
        a.aa("CellStyleRequestedEventArgs", function () { return new CellStyleRequestedEventArgsDescription(); });
        a.z("CellStyleRequestedEventArgs", CellStyleRequestedEventArgsDescriptionMetadata.a);
    };
    CellStyleRequestedEventArgsDescriptionMetadata.$t = markType(CellStyleRequestedEventArgsDescriptionMetadata, 'CellStyleRequestedEventArgsDescriptionMetadata');
    CellStyleRequestedEventArgsDescriptionMetadata.a = null;
    return CellStyleRequestedEventArgsDescriptionMetadata;
}(Base));
export { CellStyleRequestedEventArgsDescriptionMetadata };
